@@ -503,13 +503,16 @@ rfnames_remove_all_hidden (RFnames *rf_names)
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Restore original file name in selected RFitem objects on list.
+ * @brief  Restore original file name of selected RFitem on list if it matches
+ *         the fun return value.
  */
-void
-rfnames_restore_selected (RFnames *rf_names)
+static void
+rfnames_restore (RFnames   *rf_names,
+                 gboolean (*fun) (const RFitem *rf_item))
 {
-    for (uint_fast32_t i = 0; i < rf_names->cnt; ++i) {
-        if (rfitem_get_checked (rf_names->rf_items[i])) {
+    uint_fast32_t i = rf_names->cnt;
+    while (i--) {
+        if (fun (rf_names->rf_items[i])) {
             rfitem_entry_restore (rf_names->rf_items[i]);
         }
     }
@@ -526,6 +529,51 @@ rfnames_restore_all (RFnames *rf_names)
     }
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Restore original file name in selected RFitem objects on list.
+ */
+void
+rfnames_restore_selected (RFnames *rf_names)
+{
+    rfnames_restore (rf_names, rfitem_get_checked);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Restore original file name for all files from list.
+ */
+void
+rfnames_restore_all_files (RFnames *rf_names)
+{
+    rfnames_restore (rf_names, rfitem_is_file);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Restore original file name for all folders from list.
+ */
+void
+rfnames_restore_all_folders (RFnames *rf_names)
+{
+    rfnames_restore (rf_names, rfitem_is_folder);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Restore original file name for all symlinks from list.
+ */
+void
+rfnames_restore_all_symlinks (RFnames *rf_names)
+{
+    rfnames_restore (rf_names, rfitem_is_symlink);
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Restore original file name for all hidden files/folders from list.
+ */
+void
+rfnames_restore_all_hidden (RFnames *rf_names)
+{
+    rfnames_restore (rf_names, rfitem_is_hidden);
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Sort RFitem objects in RFnames list by the original path string.
  */
