@@ -271,11 +271,47 @@ void rfnames_remove_all_hidden   (RFnames *rf_names);
  *
  * @param[in,out] rf_names RFnames list to restore original names
  * @return        none
+ *
+ * @fn  void rfnames_restore_all_files (RFnames *rf_names)
+ *
+ * @brief  Restore original file name for all files from list.
+ *
+ * @param[in,out] rf_names RFnames list to restore original names
+ * @return        none
+ *
+ * @fn  void rfnames_restore_all_folders (RFnames *rf_names)
+ *
+ * @brief  Restore original file name for all folders from list.
+ *
+ * @param[in,out] rf_names RFnames list to restore original names
+ * @return        none
+ *
+ * @fn  void rfnames_restore_all_symlinks (RFnames *rf_names)
+ *
+ * @brief  Restore original file name for all symlinks from list.
+ *
+ * @param[in,out] rf_names RFnames list to restore original names
+ * @return        none
+ *
+ * @fn  void rfnames_restore_all_hidden (RFnames *rf_names)
+ *
+ * @brief  Restore original file name for all hidden files/folders from list.
+ *
+ * @param[in,out] rf_names RFnames list to restore original names
+ * @return        none
  */
 /*----------------------------------------------------------------------------*/
-void rfnames_restore_selected (RFnames *rf_names);
+void rfnames_restore_selected     (RFnames *rf_names);
 
-void rfnames_restore_all      (RFnames *rf_names);
+void rfnames_restore_all          (RFnames *rf_names);
+
+void rfnames_restore_all_files    (RFnames *rf_names);
+
+void rfnames_restore_all_folders  (RFnames *rf_names);
+
+void rfnames_restore_all_symlinks (RFnames *rf_names);
+
+void rfnames_restore_all_hidden   (RFnames *rf_names);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Sort RFitem objects in RFnames list by the original path string.
