@@ -24,9 +24,9 @@
  *
  * Program renames files.
  *
- * @date April 28, 2020
+ * @date June 05, 2020
  *
- * @version 1.2.7
+ * @version 1.2.8
  *
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -1300,7 +1300,7 @@ create_toolbar (GtkWidget **gw_container,
 
     /* RES button with menu */
     ti_menu_button = gtk_menu_tool_button_new (
-            create_image_widget (W_ICON_REVERT), "DEL");
+            create_image_widget (W_ICON_REVERT), "RES");
     gtk_tool_item_set_tooltip_text (ti_menu_button,
             "Restore original names for selected items");
     gtk_toolbar_insert (GTK_TOOLBAR (*gw_container), ti_menu_button, -1);
@@ -1312,10 +1312,37 @@ create_toolbar (GtkWidget **gw_container,
     menu_item = create_img_menu_item ("Restore all",
                                       NULL,
                                       W_ICON_REVERT);
-    //menu_item = gtk_menu_item_new_with_label ("Restore all");
     gtk_menu_shell_append (GTK_MENU_SHELL (gw_menu), menu_item);
     g_signal_connect_swapped (menu_item, "activate",
             G_CALLBACK (rfnames_restore_all), rd_data->names);
+    /* Restore original names for all files menu entry */
+    menu_item = create_img_menu_item ("Restore all files",
+                                      NULL,
+                                      W_ICON_REVERT);
+    gtk_menu_shell_append (GTK_MENU_SHELL (gw_menu), menu_item);
+    g_signal_connect_swapped (menu_item, "activate",
+            G_CALLBACK (rfnames_restore_all_files), rd_data->names);
+    /* Restore original names for all folders menu entry */
+    menu_item = create_img_menu_item ("Restore all directories",
+                                      NULL,
+                                      W_ICON_REVERT);
+    gtk_menu_shell_append (GTK_MENU_SHELL (gw_menu), menu_item);
+    g_signal_connect_swapped (menu_item, "activate",
+            G_CALLBACK (rfnames_restore_all_folders), rd_data->names);
+    /* Restore original names for all symlinks menu entry */
+    menu_item = create_img_menu_item ("Restore all symlinks",
+                                      NULL,
+                                      W_ICON_REVERT);
+    gtk_menu_shell_append (GTK_MENU_SHELL (gw_menu), menu_item);
+    g_signal_connect_swapped (menu_item, "activate",
+            G_CALLBACK (rfnames_restore_all_symlinks), rd_data->names);
+    /* Restore original names for all hidden files/dirs menu entry */
+    menu_item = create_img_menu_item ("Restore all hidden",
+                                      NULL,
+                                      W_ICON_REVERT);
+    gtk_menu_shell_append (GTK_MENU_SHELL (gw_menu), menu_item);
+    g_signal_connect_swapped (menu_item, "activate",
+            G_CALLBACK (rfnames_restore_all_hidden), rd_data->names);
     /* Assign menu to menu tool button and show menu */
     gtk_menu_tool_button_set_menu (GTK_MENU_TOOL_BUTTON (ti_menu_button),
                                    gw_menu);
